| Title: | A Dataset of Favourite Numbers |
|---|---|
| Description: | A dataset of favourite numbers, selected from an online poll of over 30,000 people by Alex Bellos (http://pages.bloomsbury.com/favouritenumber). |
| Authors: | Oliver Keyes [aut, cre], Alex Bellos [cph] |
| Maintainer: | Oliver Keyes <[email protected]> |
| License: | CC0 |
| Version: | 1.0.0 |
| Built: | 2026-05-07 05:16:04 UTC |
| Source: | https://github.com/cran/favnums |
This package provides a dataset of favourite numbers, selected from an online poll of over 30,000 people by Alex Bellos
favourite_numbers and the original dataset.
A dataset containing the favourite numbers selected by over 30,000 people in an online poll.
favourite_numbersfavourite_numbers
A data frame with 1123 rows and 4 variables:
the actual number chosen. May be NA in the case of "imaginary" numbers, or Infinite.
the number of times this number was chosen.
the percentage of user answers a particular number represents.
descriptions of the number's importance, as provided by Alex Bellos. Often NA.
http://pages.bloomsbury.com/favouritenumber
head(favourite_numbers)head(favourite_numbers)